pub struct GpuManagementTasks { /* private fields */ }Expand description
A collection of GPU management tasks.
This struct is used to send commands to the GPU management tasks. It’s also application state that gets cloned and passed to request handlers by actix-web.
Implementations
Sourceimpl GpuManagementTasks
impl GpuManagementTasks
Sourcepub fn start<T>(gpus: Vec<T>) -> Result<Self, ZeusdError>where
T: GpuManager + Send + 'static,
pub fn start<T>(gpus: Vec<T>) -> Result<Self, ZeusdError>where
T: GpuManager + Send + 'static,
Start GPU management tasks for the given GPUs. It’s generic over the type of GPU manager to allow for testing.
Sourcepub fn device_count(&self) -> usize
pub fn device_count(&self) -> usize
Return the number of GPUs managed by these tasks.
Sourcepub fn send_command_nonblocking(
&self,
gpu_id: usize,
command: GpuCommand,
request_start_time: Instant,
) -> Result<(), ZeusdError>
pub fn send_command_nonblocking( &self, gpu_id: usize, command: GpuCommand, request_start_time: Instant, ) -> Result<(), ZeusdError>
Send a command to the corresponding GPU management task and immediately return
without checking the result. Results will be logged via tracing.
Returns Ok(()) if the command was sent successfully.
Sourcepub async fn send_command_blocking(
&self,
gpu_id: usize,
command: GpuCommand,
request_start_time: Instant,
) -> Result<GpuResponse, ZeusdError>
pub async fn send_command_blocking( &self, gpu_id: usize, command: GpuCommand, request_start_time: Instant, ) -> Result<GpuResponse, ZeusdError>
Send a command to the corresponding GPU management task and wait for completion.